## code to prepare `griwrm` dataset goes here
library(tidyverse)
library(openxlsx2)
library(httr)
pkgload::load_all()

file_griwrm <- "inst/seinebasin2.tsv"
file_indicators <- "inst/seinebasin2_calibation_indicators.tsv"
url_hydroclim <- "https://hydrogr.github.io/BDD-HydroClim/images/fr/%s_INRAE_BDD-HydroClim_fact_sheet_FR.png"
url_seinebasin2_airgr_plots <- "https://nextcloud.inrae.fr/s/dweGCFJoke5R6qc/download?path=%%2FOM_influenced&files=airGR_%s_%s_1959_2022.png"

if (!file.exists(file_griwrm)) {
  download.file(
    "https://forgemia.inra.fr/in-wop/seinebasin2/-/raw/v0.4.0/inst/griwrm_v2.0.tsv?ref_type=tags",
    destfile = file_griwrm
  )
}
df <- readr::read_tsv(file_griwrm)

if (!file.exists(file_indicators)) {
  download.file(
    "https://nextcloud.inrae.fr/s/adinzGa3AmLEXnZ/download?path=%2F02-calibration%2Fv2.0&files=Q_indicators_influenced.tsv",
    destfile = file_indicators
  )
}
dfInd <- readr::read_tsv(file_indicators)
df <- df |> left_join(dfInd, by = join_by(id_amont == Id))

create_valid_link <- function(wb, pattern, df, i, j, ...) {
  url <- sprintf(pattern, ...)
  resp <- HEAD(url)
  if (status_code(resp) == 200) {
    message("Creating link: ", url)
    x <- create_hyperlink(
      sheet = 1,
      text = df[i, j],
      file = url
    )
    wb <- wb |>
      wb_add_formula(
        x = x,
        start_row = i + 1,
        start_col = j
      )
  } else {
    warning("URL error: ", url)
  }
  return(wb)
}

# Set up Excel sheet
wb <- wb_workbook() |> wb_add_worksheet() |> wb_add_data(x = df)

# Add links to airGR calibration plots
for (i in seq(nrow(df))) {
  nom_station <- iconv_filename(df$nom[i])
  wb <- wb |>
    create_valid_link(
      url_seinebasin2_airgr_plots,
      df,
      i,
      1,
      df$id_amont[i],
      nom_station
    )
}

# Add links to hydroclim sheets
station_id_cols <- c("code_station_h3", "station_cmplt_1", "station_cmplt_2")
for (j in which(names(df) %in% station_id_cols)) {
  for (i in which(!is.na(df[[j]]))) {
    wb <- wb |>
      create_valid_link(url_hydroclim, df, i, j, df[i, j, drop = TRUE])
  }
}

# Adjust column widths
wb$set_col_widths(cols = seq(ncol(df)), widths = "auto")

# write to disk
wb |> wb_save("inst/stations_seinebasin2.xlsx")
